#!/bin/sh

#**************************************************************************
#IBM Tivoli Monitoring for Web Infrastructure, 5.1.0: Apache HTTP Server
#Product ID=5724 - C01
#(C)Copyright IBM Corp. 2002 All Rights Reserved.
#US Government Users Restricted Rights - Use, duplication or
#disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#**************************************************************************
# Defect  Date    Who  Description
# ------  -----   ---  ----------------------------------------------
# 133473 05/11/04 mbk  Do not remove log files, add set -x to subroutines 
# 134177 06/03/04 mbk  PRODBINDIR not always set so some files not getting deleleted
#**************************************************************************

####Some of the methods are not used, but left for future enhancements

check_role()
{
    set -x
    MY_ROLES=`wgetadmin`
    echo $MY_ROLES | grep "apachewebserver_super" > /dev/null

    if [ $? = 1 ]; then
        echo "You must have the iplanetwebserver_super role"
        echo "to run this command."
        exit 1
    fi
}


remove_ws_objs()
{
    set -x
    # Delete all instances of ApacheWebServer class created on this ManagedNode.
    CO=`idlcall $CLO TMF_SysAdmin::Library::lookup_object \"ApacheWebServer\" {0} | awk -F# '{print $1}'`

    members=`objcall $CO _get_members`

    if [ $? -eq 0 -a -n "$members" ];then
        echo "Removing members of ApacheWebServer class from Managed Node $MNname"
        for obj in $members
        do
            OBJ_REGION=`echo $obj | cut -f1 -d"."`
            OBJ_DISP=`echo $obj | cut -f2 -d"."`
            
            # Remove the object only if it resides on this managed node or if we are on the TMR server
            if [ "$OBJ_REGION" = "$REGION" ]; then
                if [ "$OBJ_DISP" = "$DISP" -o "$DISP" -eq 1 ]; then
                    # The unsubscription is necessary due to the ITM defect 25713
                    member_label=`idlcall $obj _get_label`
                    member_label=`eval echo $member_label`
                    echo "    unsubscribing $member_label from every Profile Manager"
                    if [ "$INTERP" = "solaris2" ]; then
                        wlookup -ar ProfileManager | awk -F\t '{print $1}' | while read prfmgr ; do
                            wunsub -l "@ProfileManager:$prfmgr" "@ApacheWebServer:$member_label#$IROname"
                        done
                    else
                        wlookup -ar ProfileManager | awk -F'\t' '{print $1}' | while read prfmgr ; do
                            wunsub -l "@ProfileManager:$prfmgr" "@ApacheWebServer:$member_label#$IROname"
                        done
                    fi
                    # Now remove the objects
                    echo "    removing $obj"
                    idlcall -T top $obj remove
                fi
            fi
        done
    fi  
}


remove_class()
{
    set -x
    # Delete all the instances of the class
    CO=`idlcall $CLO TMF_SysAdmin::Library::lookup_object \"$1\" {0} | awk -F# '{print $1}'`


    if [ "$1" = "ApacheWebServer" ];then
        # Remove ApacheWebServer objects
        remove_ws_objs

        # Remove ApacheWebServer resource from every Policy Region
        echo "Removing ApacheWebServer resource from every Policy Region"
        # Retrieve all the Policy Region names
        if [ "$INTERP" = "solaris2" ];then
            wlookup -ar PolicyRegion | grep $REGION | awk -F\t '{print $1}' | while read region ; do
                 wsetpr -r ApacheWebServer @PolicyRegion:"$region"  > /dev/null 2>&1
            done
        else
            wlookup -ar PolicyRegion | grep $REGION | awk -F'\t' '{print $1}' | while read region ; do
                wsetpr -r ApacheWebServer @PolicyRegion:"$region"  > /dev/null 2>&1
            done
        fi

    else
        # Remove class objects
        members=`objcall $CO _get_members`
        if [ $? -eq 0 -a -n "$members" ];then
            echo "Removing members of $1 class"
            # Now remove the objects
            for i in $members
            do
                echo "    removing $i"
                idlcall -T top $i remove
            done
        fi
    fi

    # Remove extention object only if it is not the same OID as
    # the Class OID.
    EO=`idlattr -tg $CO extension Object | awk -F# '{print $1}'`
    if [ $? -eq 0 -a -n "$EO" -a "$EO" != "$CO" ];then
        objcall $EO rmobj
    fi

    # Remove the prototypes,
    PROTOTYPES=`idlattr -tg $CO prototypes TMF_Types::ObjectList `
    if [ -n "$PROTOTYPES" -a $? -eq 0 ];then
        NUMPROTOS=`idlarg 1 $PROTOTYPES`
        COUNT=0
        ARG=2
        while [ $COUNT -ne $NUMPROTOS ]
        do
            OID=`idlarg $ARG $PROTOTYPES`
            OID=`echo $OID | awk -F# '{print $1}'`
            if [ "$OID" != "$CO" ];then
                objcall $OID rmobj
            fi
            COUNT=`expr $COUNT + 1`
            ARG=`expr $ARG + 1`
        done
    fi

    # Remove behavior object and update ManagedNode inheritency
    # check to make sure the BO is not the same as CO
    BO=`idlattr -tg $CO behavior Object `
    BO=`echo $BO | awk -F# '{print $1}'`

    # Need to update this section to remove the object inheritance for endpoint
    # objects which point to this classes behavior objects
    if [ "$1" = "ApacheEndpoint" ]; then
        ECO=`wlookup -r Classes Endpoint`
        EBO=`idlattr -tg $ECO behavior Object`
        objcall $EBO oi_remove $BO
    fi

    if [ -n "$BO" -a "$BO" != "$CO" ];then
        objcall $BO rmobj
    fi

    # Remove the class object.
    echo "Removing Class $1"
    idlcall -T top $CO TMF_SysAdmin::InstanceManager::remove
    if [ $? -ne 0 ];then
        objcall $CO rmobj
    fi

    #
    # Clean out the name registry.
    #
    ISREG=`wlookup -r Classes $1 > /dev/null 2>&1 `
    if [ $? -eq 0 ];then
        wregister -u -r Classes $1
    else
        ISDIST=`wlookup -r distinguished $1 > /dev/null 2>&1 `
        if  [ $? -eq 0 ];then
            wregister -u $1
        fi
    fi
    idlcall $TNR TMF_TNR::Resource::remove \"$1\" TRUE > /dev/null 2>&1
}


remove_unique()
{
    set -x
    CO=`idlcall $CLO TMF_SysAdmin::Library::lookup_object \"imp_$1\" {0}`
    CO=`echo $CO | awk -F# '{print $1}'`

    # Remove the class object.
    echo "Removing Class $1"
    idlcall -T top $CO TMF_SysAdmin::InstanceManager::remove
    if [ $? -ne 0 ];then
        objcall $CO rmobj
    fi

    wregister -u $1
}

remove_presentation()
{
    set -x
    echo "Removing presentation object $1"
    PRES=`wlookup -r Presentation "$1#$IROname"`
    [ ! -z "$PRES" ] && idlcall $PRES TMF_SysAdmin::PolicyDrivenBase::remove
}

# remove TMR roles and Resource roles
remove_role()
{
    set -x
    admin_coll=`wlookup Administrators`

    # remove roles from administrators
    echo "Removing Role $1"
    Admins=`wls -l /Library/Administrator | awk '{print $1}'`
    for i in $Admins
    do
        alias=`idlcall $i get_aliases | idlarg 2 | awk -F\" '{print $2}' | sed 's/\\\\\\\\/\\\\/'`
        groups=`objcall $REGION.0.0 get_principal_roles $alias | grep $1`
        for j in $groups
        do
            secgroup=`echo $j | sed 's/:/ /g'`
            cnt=1
            for k in $secgroup
            do
                if [ $cnt -eq 1 ]; then
                    newgrp=$k
                    cnt=`expr $cnt + 1 `
                else
                    if [ "$k" != "$1" ]; then
                        newgrp="$newgrp $k"
                    fi
                fi
            done
            objcall $REGION.0.0 set_principal_roles $alias $newgrp
        done
    done

    # Remove TMR roles and Resource roles
    # If the roles have already been removed, you will get marshalling
    # errors ; so check first to see if the roles exist
    # You must restart the console to see the result of the
    # remove on the desktop.
    #
    ROLES=`idlcall $admin_coll _get_supported_roles`
    echo $ROLES | grep $1 > /dev/null
    # If the specified role is in the roles continue
    if [ $? -eq 0 ] ; then

        COUNT=`echo $ROLES | idlarg 1`
        COUNT1=`expr $COUNT - 1`

        TMR_ROLES=`idlcall $admin_coll _get_supported_tmr_roles`
        echo $TMR_ROLES | grep $1  > /dev/null
        # If the specified role is in the roles continue
        if [ $? -eq 0 ] ; then

            TCOUNT=`echo $TMR_ROLES | idlarg 1`
            TCOUNT1=`expr $TCOUNT - 1`

            ROLES1=`echo $ROLES | sed 's/'"\"$1\""'//g'`
            TMR_ROLES1=`echo $TMR_ROLES | sed 's/'"\"$1\""'//g'`

            ROLES=`echo $ROLES1 | sed 's/'"$COUNT"'/'"$COUNT1"'/g'`
            TMR_ROLES=`echo $TMR_ROLES1 | sed 's/'"$TCOUNT"'/'"$TCOUNT1"'/g'`

            idlcall $admin_coll _set_supported_roles $ROLES
            idlcall $admin_coll _set_supported_tmr_roles $TMR_ROLES
        fi
     fi
}


delete_roles()
{

    set -x
    remove_role apachewebserver_user
    remove_role apachewebserver_admin
    remove_role apachewebserver_super

}



remove_rm()
{
    set -x
    echo "Removing Resource Models"
    wdmrm -remove Apache_Performance 1>/dev/null 2>&1
    wdmrm -remove Apache_ServerAvailability 1>/dev/null 2>&1
    wdmrm -remove Apache_WebSiteAvailability 1>/dev/null 2>&1

}

update_managed_resources()
{
    set -x
# Begin section change
#
# Need to modify this section to include the classes which are managed
# resources for policy regions
#
    if [ "$1" = "ApacheWebServer" ]
    then
        echo "Updating managed resources"
        for x in `wls -l /Library/PolicyRegion | awk '{print $1}'`
        do
        LABEL=`idlattr -tg $x label Object`
        HASMR=`wgetpr "@$LABEL#$IROname" | grep $1`
        if [ -n "$HASMR" ]
        then
            wsetpr -r $HASMR "@$LABEL"
        fi
        done
    fi
# End section change
#
}

update_ProductInfo()
{
    set -x
    # removes the node from the ProductInfo and PatchInfo objects
    # related to the application.
    echo "Updating Product and Patch objects"
    PROD="$1#$IROname"
    NODE=\"$2\"
    PROD_IO=`wlookup -r ProductInfo "$PROD"`
    if [ -n "$PROD_IO" ]; then
        PATCH_IOS=`idlcall $PROD_IO _get_patches`
        NUM=`idlarg 1 $PATCH_IOS`
        NUM=`expr "$NUM" + 2 `
        COUNT=2
        while [ "$COUNT" -lt "$NUM" ]
        do
            PATCH_IO=`idlarg $COUNT $PATCH_IOS`
            idlcall $PATCH_IO remove_host_locations '{ 1' $NODE '}'
            COUNT=`expr "$COUNT" + 1 `
        done
        idlcall $PROD_IO remove_host_locations '{ 1' $NODE '}'
    fi
}

remove_ProductInfo()
{
    set -x
    # removes the node from the ProductInfo and PatchInfo objects
    # related to the application.
    echo "Removing Product and Patch objects"
    PROD="$1#$IROname"
    PROD_IO=`wlookup -r ProductInfo "$PROD"`
    if [ ! -z "$PROD_IO" ]; then
        PATCH_IOS=`idlcall $PROD_IO _get_patches`
        NUM=`idlarg 1 $PATCH_IOS`
        NUM=`expr "$NUM" + 2 `
        COUNT=2
        while [ "$COUNT" -lt "$NUM" ]
        do
            PATCH_IO=`idlarg $COUNT $PATCH_IOS`
            idlcall $PATCH_IO TMF_SysAdmin::PolicyDrivenBase::remove
            COUNT=`expr "$COUNT" + 1 `
        done
        idlcall $PROD_IO TMF_SysAdmin::PolicyDrivenBase::remove
    fi
}


delete_prfmgr()
{
    set -x
    # removes all the profile managers of the specified policy region
    REG_NAME="$1"
    OFS=$IFS
    PROFMGRS=`wls -l @PolicyRegion:"$REG_NAME" | grep "ProfileManager" | awk -F# '{print $3}' | cut -f2 | awk -F+ '{printf("%s+",$1)}'`
    IFS=+
    for profilemgr in $PROFMGRS
    do 
        echo "Deleting Profile Manager $profilemgr#$IROname"
        wunsub "-la" @ProfileManager:"$profilemgr#$IROname"
        PROFILES=`wls -l @ProfileManager:"$profilemgr#$IROname" | awk -F# '{print $3}' | cut -f2 | awk -F+ '{printf("%s+", $1)}'`
        for prf in $PROFILES
        do 
            echo "    deleting Profile $prf"
            type=`wls -l @ProfileManager:"$profilemgr#$IROname" | grep "$prf" | awk -F# '{print $2}' | awk -F: '{print $1}'`
            if [ "$type" = "TMW2K" ]; then
                wdel "@Tmw2kProfile:$prf#$IROname"
            else
                wdel "@$type:$prf"
            fi
        done
        wdel @ProfileManager:"$profilemgr#$IROname"
    done
    IFS=$OFS
}


delete_tasklibs()
{
    set -x
    # removes all the task libraries of the specified policy region
    REG_NAME="$1"
    TASKLIBS=`wls -l @PolicyRegion:"$REG_NAME" | grep "TaskLibrary" | awk -F# '{print $3}' | cut -f2 | awk -F+ '{printf("%s+",$1)}'`

    OFS=$IFS
    IFS=+
    for tasklibr in $TASKLIBS
    do 
        IFS=$OFS
        echo "Deleting Task Library '$tasklibr#$IROname'"
        
        TASKLIB=`wlookup -r TaskLibrary "$tasklibr#$IROname" | cut -f1 -d"#"`
        TSKS=`idlcall $TASKLIB list_tasks`
        
        TSKCOUNT=`idlarg 1 $TSKS`
        COUNT=0
        ARG=2
        while [ "$COUNT" -lt "$TSKCOUNT" ]
        do
            TSK=`idlarg $ARG $TSKS`
            echo "    deleting Task $TSK"
            idlcall $TASKLIB delete_task $TSK
            COUNT=`expr "$COUNT" + 1 `
            ARG=`expr "$ARG" + 1 `
        done

        JOBS=`idlcall $TASKLIB list_jobs`
        
        JOBCOUNT=`idlarg 1 $JOBS`
        COUNT=0
        ARG=2
        while [ "$COUNT" -lt "$JOBCOUNT" ]
        do
            JOB=`idlarg $ARG $JOBS`
            echo "    deleting Job $JOB"
            idlcall $TASKLIB delete_job $JOB
            COUNT=`expr "$COUNT" + 1 `
            ARG=`expr "$ARG" + 1 `
        done

        wdel @TaskLibrary:"$tasklibr#$IROname"
        IFS=+
    done
    IFS=$OFS
}


remove_NoticeGroup()
{
    set -x
    echo "Removing NoticeGroup for Apache"

    # First action - unsubscribe Notice Groups from Administrator(s)
    LOG_DIR=`wtemp`
    echo "Unsubscribing Administrators from Tivoli APM Notice Groups"
    ADMINS="admins"
    wls /Administrators > $LOG_DIR$ADMINS
    while read ADMIN
    do
        wsetadmin -N "Tivoli APM" $ADMIN > /dev/null 2>&1
    done < $LOG_DIR$ADMINS
    rm $LOG_DIR$ADMINS

    # work-around to remove Notice groups. The direct remove does not always work
    echo "Removing Notice Groups"
    CO=`idlcall $CLO TMF_SysAdmin::Library::lookup_object \"TMF_Notice\" {0}`
    members=`objcall $CO _get_members`
    if [ $? -eq 0 -a -n "$members" ];then
        for i in $members
        do
            LABEL=`idlattr -tg $i label string`
            case "$LABEL" in
            \""Tivoli APM\"")
                echo "     removing Notice Group $LABEL"
                idlcall -T top $CO remove_object 'TRUE '$i' '
                Nlabel=`echo $LABEL | awk -F\" '{print $2}'`
                wregister  -r TMF_Notice -u "$Nlabel"
                objcall $i rmobj
                ;;
            esac
        done
    fi
}


remove_TagFiles()
{
    set -x
    # remove TAG files to allow re-install

    echo "Removing TagFiles"
    rm -f "$DBDIR/.installed/ITMWIAPACHE_ALIDB"

    if [ "$RMFILES" = "TRUE" ]; then
        # Apache main component TAGs
	# 133473 On Linux, PRODBINDIR below was not set so tags not being deleted
	# So delete these the old-fashioned way
        find "$BINDIR/../.." -name "ITMWIAPACHE_*" -exec rm {} \;
        find "$BINDIR/../.." -name "pa_*GWA*FP*" -exec rm {} \;
        # 134784 remove LA patch tag files
        find "$BINDIR/../.." -name "pa_ITMWIAPACHE*" -exec rm {} \;
        find "$DBDIR"/.installed -name "ITMWIAPACHE_ALIDB" -exec rm {} \;
        find "$DBDIR"/.installed -name "pa_*-GWA-FP*" -exec rm {} \;
        # 134784 remove LA patch tag files
        find "$DBDIR"/.installed -name "pa_ITMWIAPACHE*" -exec rm {} \;
        # Apache main component TAGs
        rm -f "$PRODBINDIR/$INTERP/.installed/ITMWIAPACHE_BIN"
        rm -f "$PRODBINDIR/generic_unix/.installed/ITMWIAPACHE_GBIN"
        rm -f "$PRODCATDIR/.installed/ITMWIAPACHE_CAT"
        rm -f "$PRODLCFDIR/.installed/ITMWIAPACHE_LCFNEW"
        rm -f "$PRODLIBDIR/$INTERP/.installed/ITMWIAPACHE_LIB"
        # Apache fixpack component TAGs
        find "$PRODBINDIR/$INTERP"/.installed -name "pa_*-GWA-FP*" -exec rm {} \;
        find "$PRODBINDIR"/generic_unix/.installed -name "pa_*-GWA-FP*" -exec rm {} \;
        find "$PRODCATDIR"/.installed -name "pa_*-GWA-FP*" -exec rm {} \;
        find "$PRODLCFDIR"/.installed -name "pa_*-GWA-FP*" -exec rm {} \;
        find "$PRODLIBDIR/$INTERP"/.installed -name "pa_*-GWA-FP*" -exec rm {} \;
        find "$DBDIR"/.installed -name "pa_*-GWA-FP*" -exec rm {} \;
    fi
}


remove_binaries()
{
    set -x
    echo "Removing binaries"

    if [ "$INTERP" = "w32-ix86" ]; then
        EXT=.exe
    else
        EXT=
    fi

    rm -f "$PRODBINDIR/$INTERP/bin/wapachews$EXT"
    rm -rf "$PRODBINDIR/$INTERP/TME/Apache"
    rm -rf "$PRODBINDIR/generic_unix/TME/Apache"
    rm -f "$PRODBINDIR/generic_unix/TME/APPLSVCS/SupportScripts/ApacheWebServer.pl"
    rm -f "$PRODBINDIR/generic_unix/TME/GWA510.SIG"
}


remove_lcf_files()
{
    set -x
    echo "Removing lcf files"

    rm -fr "$PRODLCFDIR/generic/Apache"
    rm -fr "$PRODLCFDIR/bin/aix4-r1/TME/Apache"
    rm -fr "$PRODLCFDIR/bin/solaris2/TME/Apache"
    rm -fr "$PRODLCFDIR/bin/linux-ix86/TME/Apache"
    rm -fr "$PRODLCFDIR/bin/w32-ix86/TME/Apache"
    rm -fr "$PRODLCFDIR/bin/linux-s390/TME/Apache"
    rm -fr "$PRODLCFDIR/bin/hpux10/TME/Apache"
    # 133929 mbk Remove ppc files
    rm -fr "$PRODLCFDIR/bin/linux-ppc/TME/Apache"

    # 134177 mbk Delete more genericly
    cd  "$PRODLCFDIR"
    find . -name Apache_* | xargs rm -rf
    find . -name apacheTask* | xargs rm -rf
}


remove_msg_cat()
{
    set -x
    echo "Removing msg cat files"

    rm -f "$PRODCATDIR/C/AboutITMWIAPACHECatalog.cat"
    rm -f "$PRODCATDIR/C/ApacheServer_msg.cat"
    rm -f "$PRODCATDIR/C/Apache_CLI.cat"
    rm -f "$PRODCATDIR/C/Apache_Performance.cat"
    rm -f "$PRODCATDIR/C/Apache_ServerAvailability.cat"
    rm -f "$PRODCATDIR/C/Apache_WebSiteAvailability.cat"
    rm -f "$PRODCATDIR/C/ApacheTaskLib.cat"
    
}

remove_cclog()
{
    set -x
    echo "Removing CCLOG binaries"

    if [ "$INTERP" = "w32-ix86" ]; then
        DESTPATH=$PRODBINDIR/$INTERP/bin
        EXT=.dll
        rm -f "$DESTPATH/cclog.$EXT"
        rm -f "$PRODLIBDIR/$INTERP/place.holder"
    else
        DESTPATH=$PRODLIBDIR/$INTERP
        if [ "$INTERP" = "aix4-r1" ]; then
            EXT=.a
        fi
        if [ "$INTERP" = "hpux10" ]; then
            EXT=.sl
        fi
        if [ "$INTERP" = "solaris2" ]; then
            EXT=.so
        fi
	# 132307 JFG New Platforms
        if [ "$INTERP" = "linux-ix86" ]; then
            EXT=.so
        fi
        if [ "$INTERP" = "linux-s390" ]; then
            EXT=.so
        fi
        rm -f "$DESTPATH/libcclog.$EXT"
    fi

    rm -f "$DESTPATH/libio.$EXT"
    rm -f "$DESTPATH/libtos.$EXT"
    rm -f "$DESTPATH/libproc.$EXT"
    rm -f "$DESTPATH/libtthred.$EXT"
    rm -f "$DESTPATH/libmsgs.$EXT"

    rm -f "$PRODLCFDIR/lib/aix4-r1/libcclog.a"
    rm -f "$PRODLCFDIR/lib/aix4-r1/libio.a"
    rm -f "$PRODLCFDIR/lib/aix4-r1/libtos.a"
    rm -f "$PRODLCFDIR/lib/aix4-r1/libproc.a"
    rm -f "$PRODLCFDIR/lib/aix4-r1/libtthred.a"
    rm -f "$PRODLCFDIR/lib/aix4-r1/libmsgs.a"
    rm -f "$PRODLCFDIR/lib/linux-ix86/libcclog.so"
    rm -f "$PRODLCFDIR/lib/linux-ix86/libio.so"
    rm -f "$PRODLCFDIR/lib/linux-ix86/libtos.so"
    rm -f "$PRODLCFDIR/lib/linux-ix86/libproc.so"
    rm -f "$PRODLCFDIR/lib/linux-ix86/libtthred.so"
    rm -f "$PRODLCFDIR/lib/linux-ix86/libmsgs.so"  
    rm -f "$PRODLCFDIR/lib/solaris2/libcclog.so"
    rm -f "$PRODLCFDIR/lib/solaris2/libio.so"
    rm -f "$PRODLCFDIR/lib/solaris2/libtos.so"
    rm -f "$PRODLCFDIR/lib/solaris2/libproc.so"
    rm -f "$PRODLCFDIR/lib/solaris2/libtthred.so"
    rm -f "$PRODLCFDIR/lib/solaris2/libmsgs.so"
    rm -f "$PRODLCFDIR/lib/w32-ix86/cclog.dll"
    rm -f "$PRODLCFDIR/lib/w32-ix86/libio.dll"
    rm -f "$PRODLCFDIR/lib/w32-ix86/libmsgs.dll"
    rm -f "$PRODLCFDIR/lib/w32-ix86/libproc.dll"
    rm -f "$PRODLCFDIR/lib/w32-ix86/libtos.dll"
    rm -f "$PRODLCFDIR/lib/w32-ix86/libtthred.dll"
    # 132307 JFG New Platforms
    rm -f "$PRODLCFDIR/lib/linux-s390/libcclog.so"
    rm -f "$PRODLCFDIR/lib/linux-s390/libio.so"
    rm -f "$PRODLCFDIR/lib/linux-s390/libtos.so"
    rm -f "$PRODLCFDIR/lib/linux-s390/libproc.so"
    rm -f "$PRODLCFDIR/lib/linux-s390/libtthred.so"
    rm -f "$PRODLCFDIR/lib/linux-s390/libmsgs.so"
    rm -f "$PRODLCFDIR/lib/hpux10/libcclog.sl"
    rm -f "$PRODLCFDIR/lib/hpux10/libio.sl"
    rm -f "$PRODLCFDIR/lib/hpux10/libtos.sl"
    rm -f "$PRODLCFDIR/lib/hpux10/libproc.sl"
    rm -f "$PRODLCFDIR/lib/hpux10/libtthred.sl"
    rm -f "$PRODLCFDIR/lib/hpux10/libmsgs.sl"    
}

remove_log_files()
{
    set -x
    echo "Removing log files"
    # 133473 - do not remove log files 
    # rm -rf "$DBDIR/GWA"
}


# 134177 Remove tec configuration file - Apaceh.pac
remove_tec_cfg_file()
{
  set -x
  if [ -f "$BINDIR/../generic_unix/TME/APPLSVCS/TEC_CONFIG/Apache.pac" ] ; then
    rm -rf "$BINDIR/../generic_unix/TME/APPLSVCS/TEC_CONFIG/Apache.pac"
  fi
}


remove_temporary_files()
{
    set -x
    echo "Removing temporary files"


}


remove_files()
{
    set -x
    # remove all the installed files (if requested)
    if [ "$RMFILES" = "TRUE" ]; then
        remove_binaries
        remove_msg_cat
        remove_lcf_files
	remove_tec_cfg_file
        #remove_cclog
        # 133473 - do not remove log files 
        # remove_log_files     
        #remove_temporary_files
    fi

}



get_gtw_label()
{
    set -x
    wlookup -ar Gateway | while read gtw ; do
        gtw_name=`echo $gtw | cut -f1 -d" "`
        gtw_oid=`echo $gtw | cut -f2 -d" "`
        mn=`idlattr -tg $gtw_oid resource_host Object | cut -f1 -d"#" | tr -d "\t\n "`
        if [ "$mn" = "$MNoid" ]; then
            echo "$gtw_name"
        break
        fi
    done
}



sync_gateways()
{
    set -x
    # Sync the gateway caches with the TMR
    #
    echo "Syncing Gateways with TMR"

    wlookup -ar Gateway |
    while read line ; do
      gw_name=`echo $line | cut -f1 -d" "`
      rc=`wgateway $gw_name dbcheck > /dev/null 2>&1`
    done
}

PrintUsage()
{
    set -x
   echo
   echo "This uninstall procedure accepts the general wuninst command options."
   echo "Please refer to wuninst usage"
   echo
}

main()
{
    BO=`objcall 0.0.0 self`
    if [ -z "$BO" ];then
        echo "You must have the Tivoli environment"
        echo "sourced in to run this command"
        exit 1
    fi

    while [ $# -gt 0 ]
    do
        case "$1" in
           -rmfiles|-RMFILES)   RMFILES="TRUE"
                                ;;
           -usage|-USAGE)       USAGE="TRUE"
                                ;;
           *)                   USAGE="TRUE"
                                ;;
        esac
        shift
    done

    if [ "$USAGE" = "TRUE" ]; then
       PrintUsage;
       exit 0;
    fi

    #=================================================
    #=  Setup Logging
    #=================================================
        LOGDIR="$DBDIR/GWA/logs"
        if [ ! -d $LOGDIR ]; then
           mkdir -p $LOGDIR
        fi

        # Use ITMCS rolling logs function if available
        # if not found, log the old way
        # need bindir (install dir) setup to find ITMCS install directory
        OSERV=`objcall 0.0.0 get_oserv`
        export OSERV

        INST_DIR=`objcall $OSERV query install_dir`
        export INST_DIR
        case "$INTERP" in
           w32-ix86) INSTDIR=`env | grep "INST_DIR" | awk -F= '{print $2}' | sed -e 's,\\\\,/,g'`;;
           *) INSTDIR=$INST_DIR;;
        esac

        BINDIR=$INSTDIR/$INTERP

        TASKNAME="itmapache_uninstall_prod"
        if [ -f "$BINDIR"/TME/APPLSVCS/ITMCSUtils.sh ] ; then
          . "$BINDIR"/TME/APPLSVCS/ITMCSUtils.sh
          ITMCS_rolling_log_init "GWA" "${TASKNAME}" ""
        else

          LOGFILE=$LOGDIR/trace_itmapache_uninstall_prod.log

          # redirect stderr to the logfile
          umask 002
          rm "$LOGFILE" 2> /dev/null
          exec 2> "$LOGFILE"

          echo "*** Starts on `date`">&2

          # dump environment variables

          echo "==================================">&2
          echo "= Environment Variables Start...">&2
          echo "==================================">&2
          ENVS=`set`
          echo "$ENVS">&2
          echo "">&2
          echo "==================================">&2
          echo "">&2

          echo "==================================">&2
          echo "= Main Code Start...">&2
          echo "==================================">&2
        fi

        # 115653 6/12/03 mbk  Use "set -x" even when using ITMCSUtils (rolling logs)
        set -x
        set +e


    OSERV=`objcall $BO getattr oserv`
    EXECDIR=`objcall $OSERV query install_dir`
    TOP=`dirname $EXECDIR`
    DBDIR=`objcall $OSERV query db_dir`
    INTERP=`objcall $OSERV query interp`
    BINDIR=$EXECDIR/$INTERP
    DISP=`echo $OSERV |awk -F. '{print $2}'`
    REGION=`echo $OSERV | awk -F. '{print $1}'`
    CLO=`wlookup Library`
    TNR=`wlookup NameRegistry`
    MNname=`wlookup -ar ManagedNode | grep $REGION'\\.'$DISP'\\.' | awk '{print $1}'`
    MNoid=`wlookup -ar ManagedNode | grep $REGION'\\.'$DISP'\\.' | awk '{print $2}' | cut -f1 -d"#" | tr -d "\t\n "`

    IRO=`wlookup InterRegion`
    IROname=`idlattr -t -g $IRO name string`
    IROname=`eval echo $IROname`


    #----------------------------------------------------------------------
    # This whole section of code is for finding out
    # where all of the components are installed.
    #----------------------------------------------------------------------
    PRODOID=`wlookup -r ProductInfo ITMWIAPACHE`
    PRODTMPDIR=`wtemp`
    DIRS_TEMP=dirs_temp
    rm -f  $PRODTMPDIR$DIRS_TEMP

    #
    # need to put the data in a variable so that we can use echo
    # to put a carrige return at the end of the line.
    #
    data=`idlcall $PRODOID get_host_locations "{ 1 \"$MNname\" }"`

    if [ "$INTERP" = "w32-ix86" ];then
        echo $data | tr "'{'" "\n" | grep $MNname | \
        while read line ; do
        host=`echo $line | cut -f2 -d"\""`
        path=`echo $line | cut -f4 -d"\""`
        # path contains a space and then the interp
        plain_path=`echo $path | cut -f1 -d" "`
        tag=`echo $line | cut -f6 -d"\""`

        if [ ! -z "$tag" ]; then
            echo " $tag "=$plain_path >> $PRODTMPDIR$DIRS_TEMP
        fi
        done
    else
        echo $data | tr "{" "\n" | grep $MNname | \
        while read line ; do
        host=`echo $line | cut -f2 -d"\""`
        path=`echo $line | cut -f4 -d"\""`
        # path contains a space and then the interp
        plain_path=`echo $path | cut -f1 -d" "`
        tag=`echo $line | cut -f6 -d"\""`

        if [ ! -z "$tag" ]; then
            echo " $tag "=$plain_path >> $PRODTMPDIR$DIRS_TEMP
        fi
        done
    fi

    PRODBINDIR=`grep " BIN " $PRODTMPDIR$DIRS_TEMP | cut -f2 -d"="`
    # 134177 If PRODBINDIR not set, set it to BINDIR/..
    if [ x"$PRODBINDIR" = x ] ; then
      PRODBINDIR="$EXECDIR"
    fi

    # 134177 ALIDBDIR not used
    # PRODALIDBDIR=`grep " ALIDB " $PRODTMPDIR$DIRS_TEMP | cut -f2 -d"="`

    PRODCATDIR=`grep " CAT " $PRODTMPDIR$DIRS_TEMP | cut -f2 -d"="`
    # 134177 If PRODCATDIR not set, set it to tivoli part of $NLSPATH
    if [ x"$PRODCATDIR" = x ] ; then
      PRODCATDIR=`echo $NLSPATH | awk -F"%" '{print $1}'`
    fi

    PRODLIBDIR=`grep " LIB " $PRODTMPDIR$DIRS_TEMP | cut -f2 -d"="`
    # 134177 If PRODLIBDIR not set, set it to $BINDIR/../../lib
    if [ x"$PRODLIBDIR" = x ] ; then
      PRODLIBDIR="$BINDIR/../../lib"
    fi


    rm -f  $PRODTMPDIR$DIRS_TEMP

    PRODLCFDIR="$PRODBINDIR/lcf_bundle.40"

    #----------------------------------------------------------------------
    #Verify is this uninstallation is performed just after a (broken) installation looking 
    #if at least an ApacheWebServer object exists. If it does not exist the apachewebserver_super is not needed
    #----------------------------------------------------------------------
    CO=`idlcall $CLO TMF_SysAdmin::Library::lookup_object \"ApacheWebServer\" {0} | awk -F# '{print $1}'`
    members=`objcall $CO _get_members`
    if [ $? -eq 0 -a -n "$members" ];then
        # Verify the current administrator has the necessary apachewebserver_super role.
        check_role
    fi

    #----------------------------------------------------------------------
    # determine if this is the TMR server
    #----------------------------------------------------------------------
    if [ "$DISP" -ne 1 ];then

        # Remove the ApacheWebServer objects created on this Managed Node
        remove_ws_objs
        
        # Removing the files
        remove_TagFiles
        remove_files

        # Updating the Installation Info
        update_ProductInfo ITMWIAPACHE "$MNname"

    else

        # Deleting the Task Libraries and the Profile Managers that are inside Apache Policy Region
        ApacheRegionName="Monitoring for Apache HTTP Server#$IROname"
        delete_prfmgr "$ApacheRegionName"
        delete_tasklibs "$ApacheRegionName"

        # Remove the Resource Models
        remove_rm
        
        # Removing objects of Apache product
        remove_class ApacheEndpoint
        remove_class ApacheWebServer
        remove_class imp_Apache::WebServerGUI
        remove_class ApacheWebServersPD
        remove_class imp_Apache::WebServersPDGUI

        remove_presentation ApacheWebServer
        remove_presentation ApacheWebServersPD
        remove_ProductInfo ITMWIAPACHE

        # This section will remove the policy
        # region resources created during the install
        echo "Deleting $ApacheRegionName"
        wdelpr "@$ApacheRegionName"

        echo "Deleting Dependencies"
        wdel /Library/DependencyMgr/ApacheNativeDepList
        wdel /Library/DependencyMgr/ApacheJavaDepList

        # Put the IR in replace mode for the new irpopulate in next install
        IR=`wlookup InterfaceRepository`
        idlattr -t -s $IR replace_mode boolean TRUE

        # Remove the product specific roles
        delete_roles

        # Removing the files
        remove_TagFiles
        remove_files


        # This section will unregister the ITMWIApache from the wuninst list
        wregister -u -r Uninstall ITMWIAPACHE

        sync_gateways
    fi
}

#######################################
#######################################
# main starts here
#######################################
#######################################
main $@

echo "Uninstall Complete"
echo "Uninstall Complete">&2
exit 0
